@@ -1,6 +1,6 @@
 package Gerrit::REST;
 {
-  $Gerrit::REST::VERSION = '0.008';
+  $Gerrit::REST::VERSION = '0.009';
 }
 # ABSTRACT: A thin wrapper around Gerrit's REST API
 
@@ -107,7 +107,8 @@ sub _content {
 sub GET {
     my ($self, $resource) = @_;
 
-    $self->{rest}->GET("/a$resource");
+    eval { $self->{rest}->GET("/a$resource") };
+    die Gerrit::REST::Exception->new($@) if $@;
 
     return $self->_content();
 }
@@ -115,7 +116,8 @@ sub GET {
 sub DELETE {
     my ($self, $resource) = @_;
 
-    $self->{rest}->DELETE("/a$resource");
+    eval { $self->{rest}->DELETE("/a$resource") };
+    die Gerrit::REST::Exception->new($@) if $@;
 
     return $self->_content();
 }
@@ -123,11 +125,12 @@ sub DELETE {
 sub PUT {
     my ($self, $resource, $value) = @_;
 
-    $self->{rest}->PUT(
+    eval { $self->{rest}->PUT(
         "/a$resource",
         $self->{json}->encode($value),
         {'Content-Type' => 'application/json;charset=UTF-8'},
-    );
+    ) };
+    die Gerrit::REST::Exception->new($@) if $@;
 
     return $self->_content();
 }
@@ -135,11 +138,12 @@ sub PUT {
 sub POST {
     my ($self, $resource, $value) = @_;
 
-    $self->{rest}->POST(
+    eval { $self->{rest}->POST(
         "/a$resource",
         $self->{json}->encode($value),
         {'Content-Type' => 'application/json;charset=UTF-8'},
-    );
+    ) };
+    die Gerrit::REST::Exception->new($@) if $@;
 
     return $self->_content();
 }
@@ -156,7 +160,7 @@ Gerrit::REST - A thin wrapper around Gerrit's REST API
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
 =head1 SYNOPSIS
 
